@@ -14,7 +14,7 @@ class PagesAdmin(admin.ModelAdmin):
             obj.menu.save()
 
     fieldsets = [
-        (None, {'fields': ['url', 'title', 'template']}),
+        (None, {'fields': ['url', 'title']}),
         (_('Advanced options'), {
             'classes': ('collapse',),
             'fields': ['menu', 'published']
